mailr16781 - /branches/uf_redesign/gui/controller.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on June 08, 2012 - 16:51:
Author: bugman
Date: Fri Jun  8 16:51:16 2012
New Revision: 16781

URL: http://svn.gna.org/viewcvs/relax?rev=16781&view=rev
Log:
Fix for the model-free part of the relax controller.

This was broken by the change from the pipe name to pipe bundle for 
identifying the analysis.  The
controller analysis_key() method was returning the pipe name rather than 
bundle name, causing the
matching to the status.auto_analysis object to fail.  Hence the controller 
was not updating!


Modified:
    branches/uf_redesign/gui/controller.py

Modified: branches/uf_redesign/gui/controller.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/uf_redesign/gui/controller.py?rev=16781&r1=16780&r2=16781&view=diff
==============================================================================
--- branches/uf_redesign/gui/controller.py (original)
+++ branches/uf_redesign/gui/controller.py Fri Jun  8 16:51:16 2012
@@ -252,9 +252,9 @@
         if data == None:
             return
 
-        # Return the pipe name, if it exists, as the key.
-        if hasattr(data, 'pipe_name'):
-            return data.pipe_name
+        # Return the pipe bundle, if it exists, as the key.
+        if hasattr(data, 'pipe_bundle'):
+            return data.pipe_bundle
 
 
     def create_mf(self, sizer):




Related Messages


Powered by MHonArc, Updated Fri Jun 08 17:00:01 2012